package com.bpcl.lpg.core.utill;

import org.slf4j.LoggerFactory;
import com.jcraft.jsch.SftpException;
import java.util.Iterator;
import java.util.List;
import com.jcraft.jsch.JSchException;
import com.bpcl.lpg.core.sftp.SFTPService;
import com.jcraft.jsch.ChannelSftp;
import java.util.ArrayList;
import de.hybris.platform.servicelayer.config.ConfigurationService;
import org.slf4j.Logger;

public class LpgCashMemoSTFPConnectionOperation
{
    private static final Logger LOG;
    private ConfigurationService configurationService;
    private String hostName;
    private String port;
    private String userName;
    private String password;
    private String inbound;
    private String outbound;
    private String namePrefix;
    private String inboundFileType;
    private String outboundFileType;
    private String dateFormat;
    private static final String INBOUND_FILE_TYPE = ".csv";
    private static final String FILE_TYPE = ".csv";
    ArrayList<ChannelSftp> channelSftps;
    
    public LpgCashMemoSTFPConnectionOperation() {
        this.channelSftps = new ArrayList<ChannelSftp>();
    }
    
    public ChannelSftp getSFTPConnection() throws JSchException {
        final ChannelSftp sftpConnection = SFTPService.getSftpConnection(this.getUserName(), this.getHostName(), (int)Integer.valueOf(this.getPort()), this.getPassword());
        LpgCashMemoSTFPConnectionOperation.LOG.info("Connection successful with sftp server");
        return sftpConnection;
    }
    
    public List<String> dowbloadInboundFiles() throws JSchException, SftpException {
        final ChannelSftp sftpConnection = this.getSFTPConnection();
        LpgCashMemoSTFPConnectionOperation.LOG.info("Downloading files from inbound folder");
        final String inboundFolder = this.getInbound();
        sftpConnection.cd(inboundFolder);
        final List<String> inboundFilesList = new ArrayList<String>();
        final List<ChannelSftp.LsEntry> list = sftpConnection.ls(inboundFolder);
        for (final ChannelSftp.LsEntry entry : list) {
            if (entry.getFilename() != null && entry.getFilename().startsWith(this.namePrefix)) {
                inboundFilesList.add(entry.getFilename());
            }
        }
        LpgCashMemoSTFPConnectionOperation.LOG.info("Downloading files from inbound folder is completed and no.of files is:" + inboundFilesList.size());
        this.channelSftps.add(sftpConnection);
        return inboundFilesList;
    }
    
    public void storeResponseFile(final String fileName, final String fileUploadName) throws JSchException, SftpException {
        final ChannelSftp sftpConnection = this.getSFTPConnection();
        LpgCashMemoSTFPConnectionOperation.LOG.info("Moving files to outbound folder ");
        final String outboundFolder = this.getOutbound();
        sftpConnection.cd(outboundFolder);
        sftpConnection.put(fileName, fileUploadName);
        this.channelSftps.add(sftpConnection);
    }
    
    public void deleteProcessedFiles(final List<String> list) throws JSchException, SftpException {
        final ChannelSftp sftpConnection = this.getSFTPConnection();
        final String SFTP_SOURCING_WORKING_DIR = this.getInbound();
        LpgCashMemoSTFPConnectionOperation.LOG.info("Working with " + SFTP_SOURCING_WORKING_DIR + " directory");
        LpgCashMemoSTFPConnectionOperation.LOG.info("Changing directory in sftp server");
        sftpConnection.cd(SFTP_SOURCING_WORKING_DIR);
        for (String fileName : list) {
            if (fileName != null) {
                sftpConnection.rm(fileName);
                LpgCashMemoSTFPConnectionOperation.LOG.info("Deleted processed file " + fileName);
            }
        }
        this.channelSftps.add(sftpConnection);
    }
    
    public void closeSFTPConnection() throws JSchException {
        LpgCashMemoSTFPConnectionOperation.LOG.info("Closing SFTP connections");
        for (final ChannelSftp channelSftp : this.channelSftps) {
            channelSftp.exit();
            SFTPService.disconnectChannelSftp(channelSftp);
        }
        this.channelSftps.clear();
    }
    
    public ConfigurationService getConfigurationService() {
        return this.configurationService;
    }
    
    public void setConfigurationService(final ConfigurationService configurationService) {
        this.configurationService = configurationService;
    }
    
    public String getPort() {
        return this.port;
    }
    
    public void setPort(final String port) {
        this.port = port;
    }
    
    public String getHostName() {
        return this.hostName;
    }
    
    public void setHostName(final String hostName) {
        this.hostName = hostName;
    }
    
    public String getUserName() {
        return this.userName;
    }
    
    public void setUserName(final String userName) {
        this.userName = userName;
    }
    
    public String getPassword() {
        return this.password;
    }
    
    public void setPassword(final String password) {
        this.password = password;
    }
    
    public String getInbound() {
        return this.inbound;
    }
    
    public void setInbound(final String inbound) {
        this.inbound = inbound;
    }
    
    public String getInboundFileType() {
        return this.inboundFileType;
    }
    
    public void setInboundFileType(final String inboundFileType) {
        this.inboundFileType = inboundFileType;
    }
    
    public String getNamePrefix() {
        return this.namePrefix;
    }
    
    public void setNamePrefix(final String namePrefix) {
        this.namePrefix = namePrefix;
    }
    
    public String getOutbound() {
        return this.outbound;
    }
    
    public void setOutbound(final String outbound) {
        this.outbound = outbound;
    }
    
    public String getOutboundFileType() {
        return this.outboundFileType;
    }
    
    public void setOutboundFileType(final String outboundFileType) {
        this.outboundFileType = outboundFileType;
    }
    
    public String getDateFormat() {
        return this.dateFormat;
    }
    
    public void setDateFormat(final String dateFormat) {
        this.dateFormat = dateFormat;
    }
    
    static {
        LOG = LoggerFactory.getLogger(LpgCashMemoSTFPConnectionOperation.class);
    }
}
